\name{newey.west.glm}
\title{Econometric time series variance estimators for glms}
\usage{
newey.west.glm(glm.obj, times, lag=NULL, clag=NULL)
kernelvar.glm(glm.obj,times, lag=NULL,clag=NULL, kernel=c("tukey","bartlett","parzen"))
weightvar.glm(glm.obj,times,weights)
}
\alias{kernelvar.glm}
\alias{weightvar.glm}
\alias{newey.west.glm}
\arguments{
 \item{glm.obj}{Generalised linear model object }
 \item{times}{Times at which responses were observed}
 \item{lag}{ truncation lag for weighting the variance estimator}
 \item{clag}{ tuning constant for asymptotically optimal lag}
 \item{kernel}{weighting function to use}
 \item{weights}{vector of weights for variance estimator}
}
\description{
These functions construct weighted information sandwich variance estimators for generalised linear models fitted to time series data.  These arose in the econometrics literature as estimators for misspecified Gaussian regression models.  All these estimators work by weighting the middle term in the information sandwich to ignore correlations beyond a certain lag. Asymptotic theory suggests that the optimal lag is a multiple of a power of the sample size, with the power depending on the weight function.  The lag may be specified explicitly or the multiplying constant may be given.  In the only case for which explicit values are known, the optimal constant \code{clag} is of the order of 1 (rather than 0.001 or 1000).  An arbitrary vector of weights may be specified in the \code{weightvar.glm} function.

These estimators have been improved by the addition of a bias correction and an approximate denominator degrees of freedom for test and confidence interval construction.
}

\value{
  \item{var}{estimated covariance matrix without bias correction}
  \item{bias.correction}{multiplicative bias correction}
  \item{df}{Approximate denominator degrees of freedom}
}
\references{
Newey and West (1987) "A simple, positive definite, heteroskedasticity and autocorrelation consistent covariance matrix." Econometrica 55:3;703-708.

Andrews (1991) "Heteroskedasticity and Autocorrelation Consistent Covariance Matrix Estimation" Econometrica 59:59;817-858

Lumley and Heagerty (in press) "Weighted Empirical Adaptive Variance Estimators for Correlated Data Regression" JRSSB
}
\author{Thomas Lumley}
\seealso{ \code{\link{weave.trunc}},\code{\link{weave.smooth}}}

\examples{
}
\keyword{regression}
\keyword{ts}

