\name{weave.trunc}
\title{Weighted Empirical Adaptive Variance Estimators for Time Series}
\usage{
weave.trunc(glm.obj, times, lag=NULL, ctrunc=4)
weave.smooth(glm.obj, times, lag=NULL, csmooth=4)
}

\alias{weave.trunc}
\alias{weave.smooth}
\arguments{
 \item{glm.obj}{A generalised linear model object}
 \item{times}{ Vector of times at which responses were observed}
 \item{lag}{ Maximum lag for variance estimator }
 \item{ctrunc}{ Tuning constant for automatic choice of lag }
 \item{csmooth}{ Tuning constant for automatic choice of lag }
}
\description{
Weighted Empirical Adaptive Variance Estimators (WEAVEs) give standard error estimates that are robust against model misspecification, autocorrelation and moderate non-stationarity in a time series. They are closely related to the information sandwich estimators used for \code{\link{gee}} models, but incorporate weights to allow them to work in a single time series without independent replicates. The weights are chosen based on the estimated autocorrelation function. There is usually no reason to specify the \code{\link{lag}} argument.

The estimators incorporate a small-sample bias correction and an approximate degrees of freedom for a t-distribution.
}
\value{
  \item{var}{estimated covariance matrix without bias correction}
  \item{bias.correction}{multiplicative bias correction}
  \item{df}{Approximate denominator degrees of freedom}
}
\references{Lumley and Heagerty "Weighted Empirical Adaptive Variance Estimators for Correlated Data Regression", (in press) JRSSB}
\author{Thomas Lumley}
\seealso{\code{\link{newey.west.glm}},\code{\link{kernelvar.glm}}
 }

\examples{

}
\keyword{ts}
\keyword{regression}
